# -*- coding: iso-8859-1 -*-
"""
    MoinMoin theme by Allefant, based on leftsidebarsmaller and others.
"""

from MoinMoin import wikiutil
from MoinMoin.Page import Page
from MoinMoin.theme import ThemeBase
import re

class Theme(ThemeBase):
    """ here are the functions generating the html responsible for
        the look and feel of your wiki site
    """

    name = "sand"

    def html_head(self, d):
        """ Set favicon. """
        head = ThemeBase.html_head(self, d)
        favicon = self.request.getPragma('favicon')
        if favicon:
            t = favicon.rindex(".")
            head += """\n<link rel="icon" href="%s" type="%s">""" % (favicon,
                "image/%s" % favicon[t + 1:])
        return head

    def wikipanel(self, d):
        """ Create wiki panel """
        _ = self.request.getText
        html = [
            u'<div class="sidepanel">',
            u'<h1>%s</h1>' % _("Navigation"),
            self.navibar(d),
            u'</div>',
            ]
        return u'\n'.join(html)

    def mysplitNavilink(self, text):
        request = self.request

    
        text = re.compile("\\|(.*?)\\|(.*)", re.S).findall(text)
        img, text = text[0]
        
        page = Page(request, text)
        pagename = page.page_name
        title = page.split_title(request)
        title = self.shortenPagename(title)
        link = page.link_to(request, title)

        pagename = request.normalizePagename(pagename)
        link = Page(request, pagename).link_to(request, title)[:-4] + ('<img src="%s" alt="icon" /></a>' % img)

        return pagename, link

    def extrapanel(self, d):
        """ Create games panel """
        if not hasattr(self.request.cfg, "extra_bar"): return ""
        _ = self.request.getText
        item = u'<li class="%s">%s</li>'
        current = d['page_name']
        extras = []
        for extra in self.request.cfg.extra_bar:
            pagename, link = self.mysplitNavilink(extra)
            if pagename == current:
                cls = 'wikilink current'
            else:
                cls = 'wikilink'
            extras.append(item % (cls, link))

        html = [
            u'<div class="sidepanel">',
            u'<h1>%s</h1>' % _("Games"),
            """<ul id="navibar">""",
            ] + extras + [
            u'</ul',
            u'</div>',
            ]
        return u'\n'.join(html)

    def pagepanel(self, d):
        """ Create page panel """
        _ = self.request.getText
        if self.shouldShowEditbar(d['page']):
            html = [
                u'<div class="sidepanel">',
                u'<h1>%s</h1>' % _("Page"),
                self.editbar(d),
                u'</div>',
                ]
            return u'\n'.join(html)
        return ''   
        
    def userpanel(self, d):
        """ Create user panel """
        _ = self.request.getText

        trail = self.trail(d)

        html = [
            u'<div class="sidepanel">',
            u'<h1>%s</h1>' %  _("User"),
            self.username(d),
            trail,
            u'</div>'
            ]
        return u'\n'.join(html)

    def header(self, d):
        """
        Assemble page header
        
        @param d: parameter dictionary
        @rtype: string
        @return: page header html
        """
        _ = self.request.getText

        html = [
            # Custom html above header
            self.emit_custom_html(self.cfg.page_header1),

            # Header
            u'<div id="header">',
            self.searchform(d),
            self.logo().replace("</div>", " - %s</div>" % d["page_name"]),
            u'</div>',
            
            # Custom html below header (not recomended!)
            self.emit_custom_html(self.cfg.page_header2),

            # Sidebar
            u'<div id="sidebar">',
            self.wikipanel(d),
            self.pagepanel(d),
            self.userpanel(d),
            self.extrapanel(d),
            self.credits(d),
            u'</div>',

            # Custom html above footer
            self.emit_custom_html(self.cfg.page_footer1),

            # Custom html above footer
            self.emit_custom_html(self.cfg.page_footer2),
            
self.msg(d),
            
            # Page
            self.startPage(),
            ]
        return u'\n'.join(html)
    editorheader = header
 
    def footer(self, d, **keywords):
        """ Assemble page footer
        
        @param d: parameter dictionary
        @keyword ...:...
        @rtype: string
        @return: page footer html
        """
        page = d['page']
        html = [
            # Page end
            # Used to extend the page to the bottom of the sidebar
            u'<div id="pagebottom"></div>',
            self.pageinfo(page),
            self.endPage(),
            
            # Custom html above footer
            #self.emit_custom_html(self.cfg.page_footer1),
            #self.emit_custom_html('<a href="/%s">%s</a>' % (page.page_name,
            #    page.page_name)),
            # And bellow
            #self.emit_custom_html(self.cfg.page_footer2),
            ]
        return u'\n'.join(html)


def execute(request):
    """
    Generate and return a theme object
        
    @param request: the request object
    @rtype: MoinTheme
    @return: Theme object
    """
    return Theme(request)

